## Summary

## search

### DB search

Download search results and store in `data/search/` directory. API-access not yet available.

## Links

- [Wiley](https://onlinelibrary.wiley.com/)
- [Wiley text and data mining resources](https://onlinelibrary.wiley.com/library-info/resources/text-and-datamining)
